import 'package:flutter/material.dart';

/// Semantic Colors
///
/// The semantic group of colors consists of palettes dedicated
/// for system-specific usage. Each one of these colors and their
/// palettes carries a different meaning and function.
///
/// Its main goal is to convey a specific type of information.
///
/// Neutral
///
/// The palette is by name dedicated to the construction of elements that
/// carry no specific semantic information. It serves as a foundation for
/// the majority of the interface and typography.
///
/// Primary
///
/// This color serves as a primary action color across all products for
/// elements like buttons, links, and as an indication of progress and some
/// interactive components. Use sparingly to keep the maximum impact.
///
/// Success
///
/// One of the "alert" colors, its purpose is to communicate and convey a
/// sense of success, safety, and confirmation to the user.
///
/// Info
///
/// One of the "alert" colors, its purpose is to communicate and convey an
/// informative and supportive message or feedback.
///
/// Warning
///
/// One of the "alert" colors, its purpose is to communicate and convey a
/// sense of warning, problem, or something that requires attention.
///
/// Danger colors
///
/// One of the "alert" colors, its purpose is to communicate and convey a
/// sense of danger, error, or destructive action.
abstract class OptimusColors {
  OptimusColors._();

  static const neutral0 = Color(0xFFFFFFFF);
  static const neutral25 = Color(0xFFF3F3F4);
  static const neutral50 = Color(0xFFE6E6E6);
  static const neutral100 = Color(0xFFBFBFC0);
  static const neutral200 = Color(0xFF959597);
  static const neutral300 = Color(0xFF6B6B6D);
  static const neutral400 = Color(0xFF4B4B4D);
  static const neutral500 = Color(0xFF2B2B2E);
  static const neutral700 = Color(0xFF202023);
  static const neutral800 = Color(0xFF1A1A1D);
  static const neutral900 = Color(0xFF101012);
  static const neutral1000 = Color(0xFF000000);

  static const neutral0t32 = Color(0x52FFFFFF);
  static const neutral0t64 = Color(0xA3FFFFFF);
  static const neutral500t8 = Color(0x142B2B2E);
  static const neutral500t16 = Color(0x282B2B2E);
  static const neutral500t24 = Color(0x3D2B2B2E);
  static const neutral500t32 = Color(0x512B2B2E);
  static const neutral500t40 = Color(0x662B2B2E);
  static const neutral500t48 = Color(0x7A2B2B2E);
  static const neutral1000t32 = Color(0x51000000);
  static const neutral1000t64 = Color(0xA3000000);

  static const primary50 = Color(0xFFE9EDF8);
  static const primary100 = Color(0xFFC8D1ED);
  static const primary200 = Color(0xFFA3B3E1);
  static const primary300 = Color(0xFF7E95D5);
  static const primary400 = Color(0xFF627ECC);
  static const primary500 = Color(0xFF4667C3);
  static const primary700 = Color(0xFF3754B5);
  static const primary800 = Color(0xFF2F4AAE);
  static const primary900 = Color(0xFF2039A1);

  static const primary500t8 = Color(0x144667C3);
  static const primary500t16 = Color(0x284667C3);
  static const primary500t24 = Color(0x3D4667C3);
  static const primary500t32 = Color(0x514667C3);
  static const primary500t40 = Color(0x664667C3);
  static const primary500t48 = Color(0x7A4667C3);

  static const success50 = Color(0xFFE6EFEC);
  static const success100 = Color(0xFFBFD7D1);
  static const success200 = Color(0xFF95BCB2);
  static const success300 = Color(0xFF6BA193);
  static const success400 = Color(0xFF4B8D7B);
  static const success500 = Color(0xFF2B7964);
  static const success700 = Color(0xFF206652);
  static const success800 = Color(0xFF1A5C48);
  static const success900 = Color(0xFF104936);

  static const success500t8 = Color(0x142B7964);
  static const success500t16 = Color(0x282B7964);
  static const success500t24 = Color(0x3D2B7964);
  static const success500t32 = Color(0x512B7964);
  static const success500t40 = Color(0x662B7964);
  static const success500t48 = Color(0x7A2B7964);

  static const info50 = Color(0xFFE6EEF1);
  static const info100 = Color(0xFFC1D5DC);
  static const info200 = Color(0xFF98BAC4);
  static const info300 = Color(0xFF6F9EAC);
  static const info400 = Color(0xFF50899B);
  static const info500 = Color(0xFF317489);
  static const info700 = Color(0xFF256176);
  static const info800 = Color(0xFF1F576C);
  static const info900 = Color(0xFF134459);

  static const info500t8 = Color(0x14317489);
  static const info500t16 = Color(0x28317489);
  static const info500t24 = Color(0x3D317489);
  static const info500t32 = Color(0x51317489);
  static const info500t40 = Color(0x66317489);
  static const info500t48 = Color(0x7A317489);

  static const warning50 = Color(0xFFFEF3EB);
  static const warning100 = Color(0xFFFCE0CD);
  static const warning200 = Color(0xFFFACBAC);
  static const warning300 = Color(0xFFF8B68B);
  static const warning400 = Color(0xFFF7A772);
  static const warning500 = Color(0xFFF59759);
  static const warning700 = Color(0xFFF28448);
  static const warning800 = Color(0xFFF07A3E);
  static const warning900 = Color(0xFFEE692E);

  static const warning500t8 = Color(0x14F59759);
  static const warning500t16 = Color(0x28F59759);
  static const warning500t24 = Color(0x3DF59759);
  static const warning500t32 = Color(0x51F59759);
  static const warning500t40 = Color(0x66F59759);
  static const warning500t48 = Color(0x7AF59759);

  static const danger50 = Color(0xFFFAE7E9);
  static const danger100 = Color(0xFFF3C3C8);
  static const danger200 = Color(0xFFEB9CA4);
  static const danger300 = Color(0xFFE2747F);
  static const danger400 = Color(0xFFDC5663);
  static const danger500 = Color(0xFFD63848);
  static const danger700 = Color(0xFFCC2B38);
  static const danger800 = Color(0xFFC62430);
  static const danger900 = Color(0xFFBC1721);

  static const danger500t8 = Color(0x14D63848);
  static const danger500t16 = Color(0x28D63848);
  static const danger500t24 = Color(0x3DD63848);
  static const danger500t32 = Color(0x51D63848);
  static const danger500t40 = Color(0x66D63848);
  static const danger500t48 = Color(0x7AD63848);

  static const basic = neutral500;
  static const primary = primary500;
  static const success = success500;
  static const info = info500;
  static const warning = warning500;
  static const danger = danger500;
}
